Packet

Struct Packet 

pub struct Packet {
    pub payload: Option<PayloadRange>,
    pub timestamp: Option<Timestamp>,
    pub capture_timestamp: Option<i64>,
    pub flags: Option<PacketFlags>,
    pub front_frames_to_drop: Option<u32>,
    pub back_frames_to_drop: Option<u32>,
    pub encryption_properties: Option<PacketEncryptionProperties>,
    /* private fields */
}
Describes a packet delivered via StreamSink.

Fields

payload: Option<PayloadRange>

Location of the payload for this packet. This field is required.

timestamp: Option<Timestamp>

Timestamp indicating when this packet should be presented. Omitting this field implies an unspecified_best_effort timestamp.

capture_timestamp: Option<i64>

Capture time for this packet as a system monotonic time value. This field is optional and may be set by capturers to indicate when this packet was captured.

flags: Option<PacketFlags>

Flags describing the packet. Omitting this field implies all flags are clear.

front_frames_to_drop: Option<u32>

Indicates how many frames should be dropped from the front of the output packet produced by a decoder from this input packet. This value should only be provided for compressed streams. If this field is omitted, no front frames should be dropped.

back_frames_to_drop: Option<u32>

Indicates how many frames should be dropped from the back of the output packet produced by a decoder from this input packet. This value should only be provided for compressed streams. If this field is omitted, no back frames should be dropped.

encryption_properties: Option<PacketEncryptionProperties>

Describes the encryption applied to this packet. Omitting this field implies the packet is not encrypted.